@@ -457,7 +457,7 @@ void dot_neato_layout_cb (GtkWidget *button, PluginInstance *inst)
   opts = GGOBI(getDefaultDisplayOptions)();
   opts->axes_show_p = false;
   opts->edges_undirected_show_p = true;
-  dspnew = GGOBI(newScatterplot) (0, 1, dnew, gg);
+  dspnew = GGOBI(newScatterplot) (0, 1, true, dnew, gg);
   opts->axes_show_p = true;  /*-- restore it --*/
   opts->edges_undirected_show_p = false;
 
